@@ -34,21 +34,35 @@ class Regbot:
 
 
   @classmethod
-  def buySignalGenerator(cls,opening,closing):
+  def enterSignalGenerator(cls,opening,closing,thr):
     scalledInput = cls.prepareInput(opening,closing)
-    return (cls.loadmodel().predict_proba(scalledInput)[:,1] >= 0.5).astype(int)[0]
+    return (cls.loadmodel().predict_proba(scalledInput)[:,1] > thr).astype(int)[0]
+    #return (cls.loadmodel().predict(scalledInput) > 0).astype(int)[0]
+
+  @classmethod
+  def exitSignalGenerator(cls,opening,closing,thr):
+    scalledInput = cls.prepareInput(opening,closing)
+    return (cls.loadmodel().predict_proba(scalledInput)[:,1] > thr).astype(int)[0]
     #return (cls.loadmodel().predict(scalledInput) > 0).astype(int)[0]
-    
 
 
 
 
 
-def signal(opening,closing):
-  try:
-    return Regbot.buySignalGenerator(opening,closing)
-  except Exception as e:
-    print(e)
+def signal(opening,closing,thr,sig):
+  if sig.lower() == 'enter':
+    try:
+      return Regbot.enterSignalGenerator(opening,closing,thr)
+    except Exception as e:
+      print(e)
+  if sig.lower() == 'exit':
+    try:
+      return Regbot.exitSignalGenerator(opening,closing,thr)
+    except Exception as e:
+      print(e)
+  else:
+    print(f'{sig} is not a valid option!')
+    return 
 
 
 if __name__ == '__main__':
